==> jc-1.4.0.tar.gz: javax/print/attribute/standard/Finishings.h <==
// public class javax.print.attribute.standard.Finishings

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class deda23deb77f740 javax_print_attribute_standard_Finishings

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_Finishings_H_
#define _JC_javax_print_attribute_standard_Finishings_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_Finishings$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_Finishings$sub_refs	_jc_javax_print_attribute_standard_Finishings$sub_refs;
typedef struct _jc_javax_print_attribute_standard_Finishings$sub_nonrefs	_jc_javax_print_attribute_standard_Finishings$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_Finishings$refs	_jc_javax_print_attribute_standard_Finishings$refs;
typedef struct _jc_javax_print_attribute_standard_Finishings$nonrefs	_jc_javax_print_attribute_standard_Finishings$nonrefs;
typedef struct _jc_javax_print_attribute_standard_Finishings$object	_jc_javax_print_attribute_standard_Finishings$object;

typedef struct _jc_javax_print_attribute_standard_Finishings$fields_struct	_jc_javax_print_attribute_standard_Finishings$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_Finishings$vmethods	_jc_javax_print_attribute_standard_Finishings$vmethods;
typedef const struct _jc_javax_print_attribute_standard_Finishings$vtable	_jc_javax_print_attribute_standard_Finishings$vtable;
typedef const struct _jc_javax_print_attribute_standard_Finishings$vtype	_jc_javax_print_attribute_standard_Finishings$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_Finishings$fields_struct {
	struct _jc_javax_print_attribute_standard_Finishings$object	*BIND;
	struct _jc_javax_print_attribute_standard_Finishings$object	*COVER;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH__5fBOTTOM;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH__5fLEFT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH__5fRIGHT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH__5fTOP;
	struct _jc_javax_print_attribute_standard_Finishings$object	*NONE;
	struct _jc_javax_print_attribute_standard_Finishings$object	*SADDLE__5fSTITCH;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fBOTTOM__5fLEFT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fBOTTOM__5fRIGHT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fDUAL__5fBOTTOM;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fDUAL__5fLEFT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fDUAL__5fRIGHT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fDUAL__5fTOP;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fTOP__5fLEFT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fTOP__5fRIGHT;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24Finishings;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_Finishings$fields_struct _jc_javax_print_attribute_standard_Finishings$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_Finishings$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Finishings$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_Finishings$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_Finishings$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_Finishings$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_Finishings$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Finishings$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_Finishings$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_Finishings$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_Finishings$vmethods	javax_print_attribute_standard_Finishings;
};

// Vtype
struct _jc_javax_print_attribute_standard_Finishings$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_Finishings$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Finishings$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_Finishings$refs {
    _jc_javax_print_attribute_standard_Finishings$sub_refs	javax_print_attribute_standard_Finishings;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Finishings$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_Finishings$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_Finishings$sub_nonrefs	javax_print_attribute_standard_Finishings;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_Finishings$object {
	_jc_javax_print_attribute_standard_Finishings$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_Finishings$vtype	*vtype;
	_jc_javax_print_attribute_standard_Finishings$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_Finishings$vtype _jc_javax_print_attribute_standard_Finishings$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_Finishings, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_Finishings$class_object;

#endif	/* _JC_javax_print_attribute_standard_Finishings_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/Finishings.h <==
// public class javax.print.attribute.standard.Finishings

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class deda23deb77f740 javax_print_attribute_standard_Finishings

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_Finishings_H_
#define _JC_javax_print_attribute_standard_Finishings_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_Finishings$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_Finishings$sub_refs	_jc_javax_print_attribute_standard_Finishings$sub_refs;
typedef struct _jc_javax_print_attribute_standard_Finishings$sub_nonrefs	_jc_javax_print_attribute_standard_Finishings$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_Finishings$refs	_jc_javax_print_attribute_standard_Finishings$refs;
typedef struct _jc_javax_print_attribute_standard_Finishings$nonrefs	_jc_javax_print_attribute_standard_Finishings$nonrefs;
typedef struct _jc_javax_print_attribute_standard_Finishings$object	_jc_javax_print_attribute_standard_Finishings$object;

typedef struct _jc_javax_print_attribute_standard_Finishings$fields_struct	_jc_javax_print_attribute_standard_Finishings$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_Finishings$vmethods	_jc_javax_print_attribute_standard_Finishings$vmethods;
typedef const struct _jc_javax_print_attribute_standard_Finishings$vtable	_jc_javax_print_attribute_standard_Finishings$vtable;
typedef const struct _jc_javax_print_attribute_standard_Finishings$vtype	_jc_javax_print_attribute_standard_Finishings$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_Finishings$fields_struct {
	struct _jc_javax_print_attribute_standard_Finishings$object	*BIND;
	struct _jc_javax_print_attribute_standard_Finishings$object	*COVER;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH__5fBOTTOM;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH__5fLEFT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH__5fRIGHT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*EDGE__5fSTITCH__5fTOP;
	struct _jc_javax_print_attribute_standard_Finishings$object	*NONE;
	struct _jc_javax_print_attribute_standard_Finishings$object	*SADDLE__5fSTITCH;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fBOTTOM__5fLEFT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fBOTTOM__5fRIGHT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fDUAL__5fBOTTOM;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fDUAL__5fLEFT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fDUAL__5fRIGHT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fDUAL__5fTOP;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fTOP__5fLEFT;
	struct _jc_javax_print_attribute_standard_Finishings$object	*STAPLE__5fTOP__5fRIGHT;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24Finishings;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_Finishings$fields_struct _jc_javax_print_attribute_standard_Finishings$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_Finishings$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Finishings$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_Finishings$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_Finishings$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_Finishings$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_Finishings$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Finishings$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_Finishings$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_Finishings$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_Finishings$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_Finishings$vmethods	javax_print_attribute_standard_Finishings;
};

// Vtype
struct _jc_javax_print_attribute_standard_Finishings$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_Finishings$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Finishings$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_Finishings$refs {
    _jc_javax_print_attribute_standard_Finishings$sub_refs	javax_print_attribute_standard_Finishings;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Finishings$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_Finishings$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_Finishings$sub_nonrefs	javax_print_attribute_standard_Finishings;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_Finishings$object {
	_jc_javax_print_attribute_standard_Finishings$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_Finishings$vtype	*vtype;
	_jc_javax_print_attribute_standard_Finishings$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_Finishings$vtype _jc_javax_print_attribute_standard_Finishings$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_Finishings, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_Finishings$class_object;

#endif	/* _JC_javax_print_attribute_standard_Finishings_H_ */
